#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-paths
version:              0.1.0.12
visibility:           public
id:                   ghc-paths-0.1.0.12-2xWgOnBVsu4JfFnY8cTnGw
key:                  ghc-paths-0.1.0.12-2xWgOnBVsu4JfFnY8cTnGw
license:              BSD-3-Clause
copyright:            (c) Simon Marlow
maintainer:           Simon Marlow <marlowsd@gmail.com>
author:               Simon Marlow
stability:            stable
synopsis:             Knowledge of GHC'\''s installation directories
description:          Knowledge of GHC'\''s installation directories
category:             Development
abi:                  c684e30e75b5b64535432137150dd999
exposed:              True
exposed-modules:      GHC.Paths
import-dirs:          /usr/lib/ghc-8.10.5/site-local/ghc-paths-0.1.0.12
library-dirs:         /usr/lib/ghc-8.10.5/site-local/ghc-paths-0.1.0.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/ghc-paths-0.1.0.12
hs-libraries:         HSghc-paths-0.1.0.12-2xWgOnBVsu4JfFnY8cTnGw
depends:              base-4.14.2.0
haddock-interfaces:   /usr/share/doc/haskell-ghc-paths/html/ghc-paths.haddock
haddock-html:         /usr/share/doc/haskell-ghc-paths/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

